@@ -2,8 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import product
-from . import sale
+
+from . import product, sale
 
 __all__ = ['register']
 
@@ -19,6 +19,11 @@ def register():
         sale.AmendmentLine,
         module='sale_product_customer', type_='model',
         depends=['sale_amendment'])
+    Pool.register(
+        sale.LineBlanketAgreement,
+        sale.BlanketAgreementLine,
+        module='sale_product_customer', type_='model',
+        depends=['sale_blanket_agreement'])
     Pool.register(
         module='sale_product_customer', type_='wizard')
     Pool.register(
